@@ -159,16 +159,48 @@ mc2est <- function(fit,
     #                     fit = fit,
     #                     p_free = p_free,
     #                     est_df = est_df0)
+
+    type <- cond_indirect_check_fit(fit)
+
+    if (type == "lavaan") {
+      # Precompute the matching index to avoid using merge()
+      est_df0$row_id <- seq_len(nrow(est_df0))
+      ptable_template <- as.data.frame(fit@ParTable)
+      if ("group" %in% colnames(est_df0)) {
+        ptable_tmp <- ptable_template[, c("lhs", "op", "rhs", "block", "group")]
+      } else {
+        ptable_tmp <- ptable_template[, c("lhs", "op", "rhs")]
+      }
+      tmp <- merge(ptable_tmp,
+                   est_df0,
+                   all.x = TRUE,
+                   sort = FALSE)
+      select_id <- which(!is.na(tmp$row_id))
+      match_id <- tmp$row_id[select_id]
+      est_df0$row_id <- NULL
+
+    } else {
+      ptable_template <- NULL
+      match_id <- NULL
+      select_id <- NULL
+    }
+
     if (progress) {
         out_all <- suppressWarnings(pbapply::pblapply(mc_est, set_est_i,
                                                      fit = fit,
                                                      p_free = p_free,
-                                                     est_df = est_df0))
+                                                     est_df = est_df0,
+                                                     ptable = ptable_template,
+                                                     match_id = match_id,
+                                                     select_id = select_id))
       } else {
         out_all <- suppressWarnings(lapply(mc_est, set_est_i,
                                            fit = fit,
                                            p_free = p_free,
-                                           est_df = est_df0))
+                                           est_df = est_df0,
+                                           ptable = ptable_template,
+                                           match_id = match_id,
+                                           select_id = select_id))
       }
     out_all
   }
@@ -199,16 +231,33 @@ mc2implied <- function(fit,
     # out_all <- lapply(mc_est, get_implied_i,
     #                     fit = fit,
     #                     fit_tmp = fit_tmp)
+    ovnames <- lavaan::lavNames(fit, "ov")
+    lvnames <- lavaan::lavNames(fit, "lv")
+    if (!is.null(fit_tmp)) {
+      ovnames_tmp <- lavaan::lavNames(fit_tmp, "ov")
+      lvnames_tmp <- lavaan::lavNames(fit_tmp, "lv")
+    } else {
+      ovnames_tmp <- NULL
+      lvnames_tmp <- NULL
+    }
     if (progress) {
         out_all <- suppressWarnings(pbapply::pblapply(mc_est,
                                                       get_implied_i,
                                                       fit = fit,
-                                                      fit_tmp = fit_tmp))
+                                                      fit_tmp = fit_tmp,
+                                                      ovnames = ovnames,
+                                                      lvnames = lvnames,
+                                                      ovnames_tmp = ovnames_tmp,
+                                                      lvnames_tmp = lvnames_tmp))
       } else {
         out_all <- suppressWarnings(lapply(mc_est,
                                            get_implied_i,
                                            fit = fit,
-                                           fit_tmp = fit_tmp))
+                                           fit_tmp = fit_tmp,
+                                           ovnames = ovnames,
+                                           lvnames = lvnames,
+                                           ovnames_tmp = ovnames_tmp,
+                                           lvnames_tmp = lvnames_tmp))
       }
     out_all
   }
