@@ -1,10 +1,10 @@
 skip_on_cran()
-skip_if_not_installed("semTools")
-# Require semTools
+skip_if_not_installed("lavaan.mi")
+# Require lavaan.mi
 library(testthat)
 library(manymome)
 suppressMessages(library(lavaan))
-suppressMessages(library(semTools))
+suppressMessages(library(lavaan.mi))
 
 fn <- system.file("extdata", "mi_test_data.RData", package = "manymome")
 load(fn)
